icsemantic.catalog.tests.test_setup.TestOntoCatalogSetup

Package platecom :: Package ontocatalog :: Package tests :: Module test_setup :: Class TestOntoCatalogSetup |
[hide private]
[frames] | no frames]

# Class TestOntoCatalogSetup

source code

    Products.PloneTestCase.PloneTestCase.PloneTestCase --+
                                                         |
                                  base.OntoCatalogTestCase --+
                                                             |
                                                            TestOntoCatalogSetup

Testing the product setup

Instance Methods | [hide private]
test_langview_installed(self) Test that plantecom.langview is installed as a dependency | source code
test_pluggablecatalog_installed(self) Test that pluggablecatalog is installed as a dependency | source code
test_linguaplone_installed(self) Test that LinguaPlone is installed as a dependency | source code
test_ontoplone_installed(self) Test that icsemantic.thesaurus is installed as a dependency | source code
test_synonym_index_added(self) Test that a new SynonymIndex was added to the catalog | source code
test_related_index_added(self) Test that a new RelatedIndex was added to the catalog | source code
test_translation_index_added(self) Test that a new TranslationIndex was added to the catalog | source code
test_advanced_search(self) Test that the criteria from OntoCatalog are turned off from the default search by default. | source code
test_ontocatalog_criteria_available_in_topics(self) Test that the OntoCatalog criteria are available to use in ATTopics. | source code
test_catalog_replaced(self) Test that the default values for a catalog search were replaced. | source code
Inherited from `base.OntoCatalogTestCase`: `setUp`